@@ -26,7 +26,7 @@ class GithubBackend(GitBackend):
         def choose_git_name(git_name):
             msg = "What name do you want to use in your git commits? "
             return click.prompt(msg, default=git_name)
-        if click.confirm("Do you have a GitHub account?"):
+        if settings.get('github_username') or click.confirm("Do you have a GitHub account?"):
             settings['github_username'] = choose_github_username(settings.get("github_username"))
             settings['github_email'] = choose_github_email(settings.get("github_email"))
             settings['git_name'] = choose_git_name(settings.get("git_name"))
